<h4> Here are some organizations that have grown their automation with SeleniumBase:</h4>

* [MIT](https://web.mit.edu/)
* [iboss](https://www.iboss.com/)
* [Akamai](https://www.akamai.com/)
* [HubSpot](https://www.hubspot.com/)
* [Veracode](https://www.veracode.com/)
* [Autodesk](https://www.autodesk.com/)
* [Broadcom](https://www.broadcom.com/)
* [FortressIQ](https://www.fortressiq.com/)
* [Thoma Bravo](https://www.thomabravo.com/)
* [Expedia Group](https://lifeatexpediagroup.com/)
* [Texture Health](https://www.texturehealth.com/)
* [Harvard Medical School](https://hms.harvard.edu/)
* [Mississippi State University](https://www.msstate.edu/)
* [Queen's University](https://www.queensu.ca/)
* [L1NNA Laboratory](https://l1nna.com/)
* [Thomson Reuters](https://www.thomsonreuters.com/)
* [CA Technologies](https://www.ca.com/)
* [Raid The Room](https://raidtheroom.com/)
* [First American](https://www.firstam.com/)
* [Origin Energy](https://www.originenergy.com.au/)
* [InterSystems](https://www.intersystems.com/)
* [StreamSets](https://streamsets.com/)
* [NerdVision](https://www.nerd.vision/)
* [Aeturnum](https://aeturnum.com/)
* [Cellebrite](https://www.cellebrite.com/en/home/)
* [Ben Fatto](http://www.benfatto.net.br)
* [GeoNode](http://geonode.org/)
* [VMware](https://www.vmware.com/)
* [Nagarro](https://www.nagarro.com/en)
* [Ark PES](https://www.arkpes.com/)
* [Evereve](https://evereve.com/)
* [WPILib](https://wpilib.org/)
* [Yandex](https://yandex.ru/)
* [netLex](https://netlex.io/en/)
* [Cubic](https://www.cubic.com/)
* [Baidu](https://www.baidu.com/)
* [HqO](https://www.hqo.co/)
* [Iver](https://www.iver.com/)
* And more...

<h3>Case Study: (<i>HubSpot</i>)</h3>

In addition to using SeleniumBase for testing the UI of their content management system, HubSpot used SeleniumBase to automate the migration of website pages from their old CMS to their new one, which saved them over one million USD and a significant amount of time.

Learn how HubSpot uses SeleniumBase for website testing by reading: [Automated Testing with Selenium](https://dev.hubspot.com/blog/bid/88880/Automated-Integration-Testing-with-Selenium-at-HubSpot#hs_cos_wrapper_name)

For more reading about automation at HubSpot, see: [The Classic "QA Team" is Obsolete](https://product.hubspot.com/blog/the-classic-qa-team-is-obsolete#hs_cos_wrapper_name)
